@@ -7,14 +7,16 @@ import tempfile
 import toml
 import shutil
 import argparse
+from .wasm_checker import check_import_section
 
-__version__ = "0.1.5"
+__version__ = "0.1.6"
 
 src_dir = os.path.dirname(__file__)
 cur_dir = os.path.abspath(os.curdir)
 
 
 #https://stackabuse.com/how-to-print-colored-text-in-python/
+#https://stackoverflow.com/questions/287871/how-do-i-print-colored-text-to-the-terminal
 HEADER = '\033[95m'
 OKBLUE = '\033[94m'
 OKCYAN = '\033[96m'
@@ -29,18 +31,25 @@ def find_target_dir(lib_name):
     parent_dir = os.path.dirname(cur_dir)
     base_name = os.path.basename(cur_dir)
     parent_toml_file = os.path.join(parent_dir, 'Cargo.toml')
-    if not os.path.exists(parent_toml_file):
+    try:
+        with open(parent_toml_file, 'r') as f:
+            cargo_toml = toml.loads(f.read())
+            members = cargo_toml['workspace']['members']
+            for member in members:
+                if base_name == member:
+                    return os.path.join(parent_dir, 'target', lib_name)
+    except FileNotFoundError:
+        return os.path.join(cur_dir, 'target')
+    except KeyError:
         return os.path.join(cur_dir, 'target')
-    with open(parent_toml_file, 'r') as f:
-        cargo_toml = toml.loads(f.read())
-        if 'workspace' in cargo_toml:
-            if 'members' in cargo_toml['workspace']:
-                members = cargo_toml['workspace']['members']
-                for member in members:
-                    if base_name == member:
-                        return os.path.join(parent_dir, 'target', lib_name)
     return os.path.join(cur_dir, 'target')
 
+def print_err(msg):
+    print(f'{FAIL}:{msg}{ENDC}')
+
+def print_warning(msg):
+    print(f'{WARNING}:{msg}{ENDC}')
+
 def run_builder():
     parser = argparse.ArgumentParser()
     subparsers = parser.add_subparsers(dest='subparser')
@@ -70,10 +79,18 @@ def run_builder():
                 if file_name == '_Cargo.toml':
                     file_name = 'Cargo.toml'
                 files[file_name] = f.read().replace('{{name}}', project_name)
-        os.mkdir(project_name)
-        for file in files:
-            with open(f'{project_name}/{file}', 'w') as f:
-                f.write(files[file])
+        try:
+            os.mkdir(project_name)
+            for file in files:
+                file_path = f'{project_name}/{file}'
+                with open(file_path, 'w') as f:
+                    f.write(files[file])
+                if file.endswith('.sh'):
+                    if not 'Windows' == platform.system():
+                        os.chmod(file_path, 0o755)
+        except FileExistsError as e:
+            print_err(f'{FAIL}: {e}')
+            sys.exit(-1)
     elif result.subparser == "build":
         if result.debug:
             build_mode = ''
@@ -97,15 +114,25 @@ def run_builder():
         os.environ['RUSTFLAGS'] = f'-C link-arg=-zstack-size={result.stack_size} -Clinker-plugin-lto'
         cmd = f'cargo +nightly build --target=wasm32-wasi --target-dir={target_dir} -Zbuild-std --no-default-features {build_mode} -Zbuild-std-features=panic_immediate_abort'
         cmd = shlex.split(cmd)
-        subprocess.call(cmd, stdout=sys.stdout, stderr=sys.stderr)
+        ret_code = subprocess.call(cmd, stdout=sys.stdout, stderr=sys.stderr)
+        if not ret_code == 0:
+            sys.exit(ret_code)
+
+        try:
+            check_import_section(f'{target_dir}/wasm32-wasi/release/{lib_name}.wasm')
+        except Exception as e:
+            print(f'{FAIL}: {e}')
+            sys.exit(-1)
 
         if shutil.which('wasm-opt'):
             cmd = f'wasm-opt {target_dir}/wasm32-wasi/release/{lib_name}.wasm -Oz -o {target_dir}/{lib_name}.wasm'
             cmd = shlex.split(cmd)
-            subprocess.call(cmd, stdout=sys.stdout, stderr=sys.stderr)
+            ret_code = subprocess.call(cmd, stdout=sys.stdout, stderr=sys.stderr)
+            if not ret_code == 0:
+                sys.exit(ret_code)
         else:
             shutil.copy(f'{target_dir}/wasm32-wasi/release/{lib_name}.wasm', f'{target_dir}/{lib_name}.wasm')
-            print(f'''{WARNING}
+            print_warning('''
 wasm-opt not found! Make sure the binary is in your PATH environment.
 We use this tool to optimize the size of your contract's Wasm binary.
 wasm-opt is part of the binaryen package. You can find detailed
@@ -134,7 +161,9 @@ There are ready-to-install packages for many platforms:
             del os.environ['RUSTFLAGS']
             cmd = f'cargo run --package abi-gen --manifest-path={temp_dir}/Cargo.toml --target-dir={target_dir} --release'
             cmd = shlex.split(cmd)
-            subprocess.call(cmd, stdout=sys.stdout, stderr=sys.stderr)
+            ret_code = subprocess.call(cmd, stdout=sys.stdout, stderr=sys.stderr)
+            if not ret_code == 0:
+                sys.exit(ret_code)
         finally:
             shutil.rmtree(temp_dir)
     else:
